@@ -4,7 +4,7 @@
 
    Author: Ilan Schnell
 */
-#define BITARRAY_VERSION  "2.8.5"
+#define BITARRAY_VERSION  "2.9.0"
 
 #ifdef STDC_HEADERS
 #  include <stddef.h>
@@ -316,3 +316,21 @@ conv_pybit(PyObject *value, int *vi)
     *vi = (int) n;
     return 1;
 }
+
+/* Return 0 if bitarrays have equal length and bit-endianness.
+   Otherwise, set exception and return -1. */
+static inline int
+ensure_eq_size_endian(bitarrayobject *a, bitarrayobject *b)
+{
+    if (a->nbits != b->nbits) {
+        PyErr_SetString(PyExc_ValueError,
+                        "bitarrays of equal length expected");
+        return -1;
+    }
+    if (a->endian != b->endian) {
+        PyErr_SetString(PyExc_ValueError,
+                        "bitarrays of equal bit-endianness expected");
+        return -1;
+    }
+    return 0;
+}
